@@ -9,6 +9,7 @@
 #include <QState>
 #include <QAbstractTransition>
 #include <QPropertyAnimation>
+#include <QCloseEvent>
 #include "slidewidget.h"
 #include "listform.h"
 #include "editform.h"
@@ -50,6 +51,8 @@ private:
 
     ListForm * listForm;
     EditForm * editForm;
+protected:
+    void closeEvent(QCloseEvent *event);
 
 private slots:
     void on_actionChecked_bottom_triggered();
